==> imageio-turbojpeg-0.2.8-sources.jar: de/digitalcollections/turbojpeg/Info.java <==
package de.digitalcollections.turbojpeg;

import de.digitalcollections.turbojpeg.lib.structs.tjscalingfactor;

import java.awt.*;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

public class Info {
  private int width;
  private int height;
  private int subsampling;
  List<Dimension> availableSizes;

  public int getWidth() {
    return width;
  }

  public int getHeight() {
    return height;
  }

  public int getSubsampling() {
    return subsampling;
  }

  public List<Dimension> getAvailableSizes() {
    return availableSizes;
  }

  private static int getScaled(int dim, int num, int denom) {
    return (dim * num + denom - 1) / denom;
  }

  public Info(int width, int height, int subsampling, tjscalingfactor[] factors) {
    this.width = width;
    this.height = height;
    this.subsampling = subsampling;
    // The available sizes are determined from the list of scaling factors.
    this.availableSizes = Arrays.stream(factors)
        .filter(f -> f.denom.get() > 0)
        .sorted(Comparator.comparing(f -> -getScaled(width, f.num.get(), f.denom.get())))
        .map(f -> new Dimension(getScaled(width, f.num.get(), f.denom.get()),
                                getScaled(height, f.num.get(), f.denom.get())))
        .filter(d -> d.width <= width && d.height <= height && d.width > 0 && d.height > 0)
        .distinct()
        .collect(Collectors.toList());
  }

  public Dimension getMCUSize() {
    switch (subsampling) {
      case 1:  // 4:2:2
        return new Dimension(16, 8);
      case 2:
        return new Dimension(16, 16);
      case 4:
        return new Dimension(8, 16);
      default:
        return new Dimension(8, 8);
    }
  }
}

==> imageio-turbojpeg-0.4.1-sources.jar: de/digitalcollections/turbojpeg/Info.java <==
package de.digitalcollections.turbojpeg;

import de.digitalcollections.turbojpeg.lib.enums.TJCS;
import de.digitalcollections.turbojpeg.lib.enums.TJSAMP;
import de.digitalcollections.turbojpeg.lib.structs.tjscalingfactor;
import java.awt.Dimension;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

public class Info {
  private int width;
  private int height;
  private TJSAMP subsampling;
  private TJCS colorspace;
  List<Dimension> availableSizes;

  public int getWidth() {
    return width;
  }

  public int getHeight() {
    return height;
  }

  public TJSAMP getSubsampling() {
    return subsampling;
  }

  public TJCS getColorspace() {
    return colorspace;
  }

  public List<Dimension> getAvailableSizes() {
    return availableSizes;
  }

  private static int getScaled(int dim, int num, int denom) {
    return (dim * num + denom - 1) / denom;
  }

  /**
   * Create a new instance with the information parsed from the JPEG image.
   */
  public Info(int width, int height, int subsampling, int colorspace, tjscalingfactor[] factors) {
    this.width = width;
    this.height = height;
    this.subsampling = TJSAMP.fromInt(subsampling);
    this.colorspace = TJCS.fromInt(colorspace);
    // The available sizes are determined from the list of scaling factors.
    this.availableSizes = Arrays.stream(factors)
        .filter(f -> f.denom.get() > 0)
        .sorted(Comparator.comparing(f -> -getScaled(width, f.num.get(), f.denom.get())))
        .map(f -> new Dimension(getScaled(width, f.num.get(), f.denom.get()),
                                getScaled(height, f.num.get(), f.denom.get())))
        .filter(d -> d.width <= width && d.height <= height && d.width > 0 && d.height > 0)
        .distinct()
        .collect(Collectors.toList());
  }

  /**
   * Get the size of the Minimum Coding Units.
   *
   * Neccessary to calculate the right cropping alignments.
   */
  public Dimension getMCUSize() {
    switch (subsampling) {
      case TJSAMP_422:  // 4:2:2
        return new Dimension(16, 8);
      case TJSAMP_420:
        return new Dimension(16, 16);
      case TJSAMP_440:
        return new Dimension(8, 16);
      default:
        return new Dimension(8, 8);
    }
  }
}
